@@ -19,7 +19,6 @@ from pipenv.cli.options import (
     skip_lock_option,
     sync_options,
     system_option,
-    three_option,
     uninstall_options,
     verbose_option,
 )
@@ -80,8 +79,8 @@ def cli(
     site_packages=None,
     **kwargs,
 ):
+    from pipenv.patched.pip._vendor import rich
     from pipenv.utils.shell import system_which
-    from pipenv.utils.spinner import create_spinner
 
     load_dot_env(state.project, quiet=state.quiet)
 
@@ -188,7 +187,10 @@ def cli(
                         )
                     )
                 )
-                with create_spinner(text="Running...", setting=state.project.s):
+
+                console = rich.console.Console()
+                # TODO: add state.project.s to spinner status
+                with console.status("Running..."):
                     # Remove the virtualenv.
                     cleanup_virtualenv(state.project, bare=True)
                 return 0
@@ -202,11 +204,10 @@ def cli(
                     err=True,
                 )
                 ctx.abort()
-    # --python or --three was passed...
-    if (state.python or state.three is not None) or state.site_packages:
+    # --python was passed...
+    if (state.python) or state.site_packages:
         ensure_project(
             state.project,
-            three=state.three,
             python=state.python,
             warn=True,
             site_packages=state.site_packages,
@@ -236,7 +237,6 @@ def install(state, **kwargs):
     do_install(
         state.project,
         dev=state.installstate.dev,
-        three=state.three,
         python=state.python,
         pypi_mirror=state.pypi_mirror,
         system=state.system,
@@ -283,7 +283,6 @@ def uninstall(ctx, state, all_dev=False, all=False, **kwargs):
         state.project,
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
-        three=state.three,
         python=state.python,
         system=state.system,
         lock=not state.installstate.skip_lock,
@@ -327,7 +326,6 @@ def lock(ctx, state, **kwargs):
     # handled in do_lock
     ensure_project(
         state.project,
-        three=state.three,
         python=state.python,
         pypi_mirror=state.pypi_mirror,
         warn=(not state.quiet),
@@ -365,7 +363,6 @@ def lock(ctx, state, **kwargs):
 )
 @argument("shell_args", nargs=-1)
 @pypi_mirror_option
-@three_option
 @python_option
 @pass_state
 def shell(
@@ -398,7 +395,6 @@ def shell(
         fancy = True
     do_shell(
         state.project,
-        three=state.three,
         python=state.python,
         fancy=fancy,
         shell_args=shell_args,
@@ -422,7 +418,6 @@ def run(state, command, args):
         state.project,
         command=command,
         args=args,
-        three=state.three,
         python=state.python,
         pypi_mirror=state.pypi_mirror,
     )
@@ -437,7 +432,7 @@ def run(state, command, args):
     "--db",
     nargs=1,
     default=lambda: os.environ.get("PIPENV_SAFETY_DB"),
-    help="Path to a local PyUp Safety vulnerabilities database."
+    help="Path or URL to a PyUp Safety vulnerabilities database."
     " Default: ENV PIPENV_SAFETY_DB or None.",
 )
 @option(
@@ -448,7 +443,7 @@ def run(state, command, args):
 )
 @option(
     "--output",
-    type=Choice(["default", "json", "full-report", "bare"]),
+    type=Choice(["default", "json", "full-report", "bare", "screen", "text", "minimal"]),
     default="default",
     help="Translates to --json, --full-report or --bare from PyUp Safety check",
 )
@@ -461,6 +456,28 @@ def run(state, command, args):
 @option(
     "--quiet", is_flag=True, help="Quiet standard output, except vulnerability report."
 )
+@option("--policy-file", default="", help="Define the policy file to be used")
+@option(
+    "--exit-code/--continue-on-error",
+    default=True,
+    help="Output standard exit codes. Default: --exit-code",
+)
+@option(
+    "--audit-and-monitor/--disable-audit-and-monitor",
+    default=True,
+    help="Send results back to pyup.io for viewing on your dashboard. Requires an API key.",
+)
+@option(
+    "--project",
+    default=None,
+    help="Project to associate this scan with on pyup.io. Defaults to a canonicalized github style name if available, otherwise unknown",
+)
+@option(
+    "--save-json",
+    default="",
+    help="Path to where output file will be placed, if the path is a directory, "
+    "Safety will use safety-report.json as filename. Default: empty",
+)
 @common_options
 @system_option
 @pass_state
@@ -469,9 +486,14 @@ def check(
     db=None,
     style=False,
     ignore=None,
-    output="default",
+    output="screen",
     key=None,
     quiet=False,
+    exit_code=True,
+    policy_file="",
+    save_json="",
+    audit_and_monitor=True,
+    project=None,
     **kwargs,
 ):
     """Checks for PyUp Safety security vulnerabilities and against PEP 508 markers provided in Pipfile."""
@@ -479,7 +501,6 @@ def check(
 
     do_check(
         state.project,
-        three=state.three,
         python=state.python,
         system=state.system,
         db=db,
@@ -487,6 +508,11 @@ def check(
         output=output,
         key=key,
         quiet=quiet,
+        exit_code=exit_code,
+        policy_file=policy_file,
+        save_json=save_json,
+        audit_and_monitor=audit_and_monitor,
+        safety_project=project,
         pypi_mirror=state.pypi_mirror,
     )
 
@@ -504,7 +530,6 @@ def update(ctx, state, bare=False, dry_run=None, outdated=False, **kwargs):
 
     ensure_project(
         state.project,
-        three=state.three,
         python=state.python,
         pypi_mirror=state.pypi_mirror,
         warn=(not state.quiet),
@@ -556,7 +581,6 @@ def update(ctx, state, bare=False, dry_run=None, outdated=False, **kwargs):
     do_sync(
         state.project,
         dev=state.installstate.dev,
-        three=state.three,
         python=state.python,
         bare=bare,
         dont_upgrade=not state.installstate.keep_outdated,
@@ -605,7 +629,6 @@ def run_open(state, module, *args, **kwargs):
     # Ensure that virtualenv is available.
     ensure_project(
         state.project,
-        three=state.three,
         python=state.python,
         validate=False,
         pypi_mirror=state.pypi_mirror,
@@ -646,7 +669,6 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
     retcode = do_sync(
         state.project,
         dev=state.installstate.dev,
-        three=state.three,
         python=state.python,
         bare=bare,
         dont_upgrade=(not state.installstate.keep_outdated),
@@ -669,7 +691,6 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
 @option("--bare", is_flag=True, default=False, help="Minimal output.")
 @option("--dry-run", is_flag=True, default=False, help="Just output unneeded packages.")
 @verbose_option
-@three_option
 @python_option
 @pass_state
 def clean(state, dry_run=False, bare=False, user=False):
@@ -678,7 +699,6 @@ def clean(state, dry_run=False, bare=False, user=False):
 
     do_clean(
         state.project,
-        three=state.three,
         python=state.python,
         dry_run=dry_run,
         system=state.system,
