@@ -2,6 +2,7 @@ import os
 
 from pipenv.project import Project
 from pipenv.utils.internet import is_valid_url
+from pipenv.vendor import click
 from pipenv.vendor.click import (
     BadArgumentUsage,
     BadParameter,
@@ -11,7 +12,6 @@ from pipenv.vendor.click import (
     echo,
     make_pass_decorator,
     option,
-    secho,
 )
 from pipenv.vendor.click import types as click_types
 from pipenv.vendor.click_didyoumean import DYMMixin
@@ -64,8 +64,6 @@ class State:
         self.quiet = False
         self.pypi_mirror = None
         self.python = None
-        self.two = None
-        self.three = None
         self.site_packages = None
         self.clear = False
         self.system = False
@@ -88,6 +86,7 @@ class InstallState:
         self.packages = []
         self.editables = []
         self.extra_pip_args = []
+        self.categories = []
 
 
 class LockOptions:
@@ -155,6 +154,15 @@ def keep_outdated_option(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
         state.installstate.keep_outdated = value
+        if value:
+            click.secho(
+                "The flag --keep-outdated has been deprecated for removal."
+                "The flag does not respect package resolver results and leads to inconsistent lock files.  "
+                "Please pin relevant requirements in your Pipfile and discontinue use of this flag.",
+                fg="yellow",
+                bold=True,
+                err=True,
+            )
         return value
 
     return option(
@@ -223,6 +231,24 @@ def _dev_option(f, help_text):
     )(f)
 
 
+def categories_option(f):
+    def callback(ctx, param, value):
+        state = ctx.ensure_object(State)
+        if value:
+            for opt in value.split(" "):
+                state.installstate.categories.append(opt)
+        return value
+
+    return option(
+        "--categories",
+        nargs=1,
+        required=False,
+        callback=callback,
+        expose_value=True,
+        type=click_types.STRING,
+    )(f)
+
+
 def install_dev_option(f):
     return _dev_option(f, "Install both develop and default packages")
 
@@ -287,28 +313,6 @@ def extra_pip_args(f):
     )(f)
 
 
-def three_option(f):
-    def callback(ctx, param, value):
-        state = ctx.ensure_object(State)
-        if value is not None:
-            secho(
-                "WARNING: --three is deprecated! pipenv uses python3 by default",
-                err=True,
-                fg="yellow",
-            )
-            state.three = value
-        return value
-
-    return option(
-        "--three",
-        is_flag=True,
-        default=None,
-        help="Use Python 3 when creating virtualenv. Deprecated",
-        callback=callback,
-        expose_value=False,
-    )(f)
-
-
 def python_option(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
@@ -533,7 +537,6 @@ def common_options(f):
     f = verbose_option(f)
     f = quiet_option(f)
     f = clear_option(f)
-    f = three_option(f)
     f = python_option(f)
     return f
 
@@ -542,11 +545,13 @@ def install_base_options(f):
     f = common_options(f)
     f = pre_option(f)
     f = keep_outdated_option(f)
+    f = extra_pip_args(f)
     return f
 
 
 def uninstall_options(f):
     f = install_base_options(f)
+    f = categories_option(f)
     f = uninstall_dev_option(f)
     f = skip_lock_option(f)
     f = editable_option(f)
@@ -558,12 +563,14 @@ def lock_options(f):
     f = install_base_options(f)
     f = lock_dev_option(f)
     f = dev_only_flag(f)
+    f = categories_option(f)
     return f
 
 
 def sync_options(f):
     f = install_base_options(f)
     f = install_dev_option(f)
+    f = categories_option(f)
     return f
 
 
@@ -575,7 +582,6 @@ def install_options(f):
     f = ignore_pipfile_option(f)
     f = editable_option(f)
     f = package_arg(f)
-    f = extra_pip_args(f)
     return f
 
 
